package
Version:
v0.1.9
Opens a new window with list of versions in this module.
Published: May 23, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Error(message string, plaintext, jsonOut bool)
Error outputs an error message
func Info(message string, plaintext, jsonOut bool)
Info outputs an informational message
func JSON(data interface{})
JSON outputs data as JSON
func Success(message string, plaintext, jsonOut bool)
Success outputs a success message
Table outputs data in table format
type TableData struct {
Rows [][]string
}
TableData represents data for table output
Source Files
¶
Click to show internal directories.
Click to hide internal directories.